import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const titleText = 'Top 10 Most Populous Countries';
const xAxisLabelText = 'Population';

const svg = select('svg');
const selector = select('select');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
 
  const population = d => d.population
  const country = d => d.country
  
  selector
  .selectAll('option')
 	.data(data)
  .enter()
	.append('option')
    .text(d => country(d))
    .attr("value", d => country(d));
  
  const selectedCountry = selector.property("value")
  
  const isCountry = (d, selectedCountry) => country(d) == selectedCountry ? "orange" : "steelblue";
  
  const leftMargin = 200;
  const topMargin = 40;
  
  const xScale = d3.scaleLinear()
  .domain([0, max(data, population)])
  .range([0, width - leftMargin])
  
  const yScale = d3.scaleBand()
  .domain(data.map(country))
  .range([0, height - topMargin])
  .padding(0.1)
  
  const xAxisTickFormat = number =>
    format('.3s')(number);
  
  const xAxis = d3.axisBottom()
    .scale(xScale)
    .tickFormat(xAxisTickFormat)
    .tickSize(-height);
  
  const yAxis = d3.axisLeft()
    .scale(yScale);
  
  svg.attr("transform", "translate(0, 30)")
  
  svg.append("g")
      .attr(`transform`, `translate(${leftMargin}, ${height - topMargin})`)
    .call(xAxis)
    .select('.domain')
    .remove();

  svg.append("g")
    .attr(`transform`, `translate(${leftMargin}, ${0})`)
    .call(yAxis)
    .selectAll('.domain, .tick line')
    .remove();
  
  svg.selectAll("rect")
    .data(data)
    .enter()
    .append("rect")
    .attr("x", leftMargin)
    .attr("y", d => yScale(country(d)))
    .attr("height", yScale.bandwidth())
    .attr("width", d => xScale(population(d)))
    .attr("fill", d => isCountry(d, selectedCountry));
  

    
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  render(data);
  

})

